Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorThomas Steur <tsteur@users.noreply.github.com>2018-01-10 21:45:20 +0300
committerGitHub <noreply@github.com>2018-01-10 21:45:20 +0300
commit82a9b1b0a01dc20928d50134233e167f0116472d (patch)
treea85fb5ecde6e9b9bacdd20f4310919daf674ab59 /plugins/Installation/ServerFilesGenerator.php
parent92cb21b63c7b971579a9f0e3da57cc7d425a3c4f (diff)
Further Piwik.org => Matomo.org replacements (#12415)
* renaming more Piwik mentions * some more updates * fix some tests * support matomo partially as require string * fix tests * fix failing system test * fix tests * fix system test * fix test
Diffstat (limited to 'plugins/Installation/ServerFilesGenerator.php')
-rw-r--r--plugins/Installation/ServerFilesGenerator.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/plugins/Installation/ServerFilesGenerator.php b/plugins/Installation/ServerFilesGenerator.php
index 1207024bfd..9118894efb 100644
--- a/plugins/Installation/ServerFilesGenerator.php
+++ b/plugins/Installation/ServerFilesGenerator.php
@@ -89,7 +89,7 @@ class ServerFilesGenerator
{
$file = $path . '/.htaccess';
- $content = "# This file is auto generated by Piwik, do not edit directly\n# Please report any issue or improvement directly to the Piwik team.\n\n" . $content;
+ $content = "# This file is auto generated by Matomo, do not edit directly\n# Please report any issue or improvement directly to the Matomo team.\n\n" . $content;
if ($overwrite || !file_exists($file)) {
@file_put_contents($file, $content);
}
@@ -279,7 +279,7 @@ HTACCESS_ALLOW;
}
/**
* Deletes all existing .htaccess files and web.config files that Piwik may have created,
*/
public static function deleteHtAccessFiles()
{
@@ -279,7 +279,7 @@ HTACCESS_ALLOW;
}
/**
- * Deletes all existing .htaccess files and web.config files that Piwik may have created,
+ * Deletes all existing .htaccess files and web.config files that Matomo may have created,
*/
public static function deleteHtAccessFiles()